==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
var ToolActionIconButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconButtonDescriptionMetadata, _super);
    function ToolActionIconButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionIconButtonDescriptionMetadata.b = function (a) {
        if (ToolActionIconButtonDescriptionMetadata.a == null) {
            ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
        }
        if (a.g(ToolActionIconButtonDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionIconButtonDescriptionMetadata.a);
    };
    ToolActionIconButtonDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionIconButtonDescriptionMetadata.d = function (a) {
        ToolActionIconButtonDescriptionMetadata.b(a);
        a.u("ToolActionIconButton", function () { return new ToolActionIconButtonDescription(); });
        a.t("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
    };
    ToolActionIconButtonDescriptionMetadata.$t = markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
}(Base));
export { ToolActionIconButtonDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
var ToolActionIconButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconButtonDescriptionMetadata, _super);
    function ToolActionIconButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionIconButtonDescriptionMetadata.b = function (a) {
        if (ToolActionIconButtonDescriptionMetadata.a == null) {
            ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
        }
        if (a.j(ToolActionIconButtonDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionIconButtonDescriptionMetadata.a);
    };
    ToolActionIconButtonDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionIconButtonDescriptionMetadata.d = function (a) {
        ToolActionIconButtonDescriptionMetadata.b(a);
        a.aa("ToolActionIconButton", function () { return new ToolActionIconButtonDescription(); });
        a.z("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
    };
    ToolActionIconButtonDescriptionMetadata.$t = markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
}(Base));
export { ToolActionIconButtonDescriptionMetadata };
